@@ -35,8 +35,7 @@ def dfs(obj, parent, name):
         dfs(arg, number, key)
 
 G = nx.Graph()
-def build_graph():
-    filename = input("enter filename: ")
+def build_graph(filename):
     with open(filename, "r") as fin:
         func_ast = ast.parse(fin.read())
     dfs(func_ast, None, "root")
